@@ -39,12 +39,21 @@ class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
 
 
 class Termo(core.models.Log):
-    nome = models.CharField(max_length=200, null=True)
+    nome = models.CharField(max_length=200, primary_key=True)
+    nome_descritivo = models.CharField(max_length=200, null=True)
+    nome_html = models.CharField(max_length=200, null=True)
     versao = models.CharField(max_length=50, null=True)
     termo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
     descricao = models.TextField(null=True)
     cliente = models.ManyToManyField('cliente.Cliente', through='cliente.ClienteTermo', through_fields=('termo', 'cliente'))
 
+    tipo_codigo = models.CharField(null=True, max_length=200)
+    tipo_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.TERMO')
+    tipo = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_termo', to_fields={
+        "codigo": "tipo_codigo",
+        "tipo": "tipo_tipo"
+    })
+
     class Meta(core.models.Log.Meta):
         abstract = False
         db_table = 'cliente_termo'
